( cd usr/bin ; rm -rf perl )
( cd usr/bin ; ln -sf perl4.036 perl )
( cd usr/bin ; rm -rf taintperl )
( cd usr/bin ; ln -sf tperl4.036 taintperl )
( cd usr/bin ; rm -rf suidperl )
( cd usr/bin ; ln -sf sperl4.036 suidperl )
( cd usr/bin ; rm -rf perl4.036 )
( cd usr/bin ; ln -sf /cdrom/live/usr/bin/perl4.036 perl4.036 )
( cd usr/bin ; rm -rf tperl4.036 )
( cd usr/bin ; ln -sf /cdrom/live/usr/bin/tperl4.036 tperl4.036 )
( cd usr/bin ; rm -rf a2p )
( cd usr/bin ; ln -sf /cdrom/live/usr/bin/a2p a2p )
( cd usr/bin ; rm -rf cppstdin )
( cd usr/bin ; ln -sf /cdrom/live/usr/bin/cppstdin cppstdin )
( cd usr/bin ; rm -rf h2ph )
( cd usr/bin ; ln -sf /cdrom/live/usr/bin/h2ph h2ph )
( cd usr/bin ; rm -rf c2ph )
( cd usr/bin ; ln -sf /cdrom/live/usr/bin/c2ph c2ph )
( cd usr/bin ; rm -rf pstruct )
( cd usr/bin ; ln -sf /cdrom/live/usr/bin/pstruct pstruct )
( cd usr/bin ; rm -rf s2p )
( cd usr/bin ; ln -sf /cdrom/live/usr/bin/s2p s2p )
( cd usr/bin ; rm -rf find2perl )
( cd usr/bin ; ln -sf /cdrom/live/usr/bin/find2perl find2perl )
( cd usr/bin ; rm -rf sperl4.036 )
( cd usr/bin ; ln -sf /cdrom/live/usr/bin/sperl4.036 sperl4.036 )
( cd usr/lib/perl4 ; rm -rf abbrev.pl )
( cd usr/lib/perl4 ; ln -sf /cdrom/live/usr/lib/perl4/abbrev.pl abbrev.pl )
( cd usr/lib/perl4 ; rm -rf assert.pl )
( cd usr/lib/perl4 ; ln -sf /cdrom/live/usr/lib/perl4/assert.pl assert.pl )
( cd usr/lib/perl4 ; rm -rf bigfloat.pl )
( cd usr/lib/perl4 ; ln -sf /cdrom/live/usr/lib/perl4/bigfloat.pl bigfloat.pl )
( cd usr/lib/perl4 ; rm -rf bigint.pl )
( cd usr/lib/perl4 ; ln -sf /cdrom/live/usr/lib/perl4/bigint.pl bigint.pl )
( cd usr/lib/perl4 ; rm -rf bigrat.pl )
( cd usr/lib/perl4 ; ln -sf /cdrom/live/usr/lib/perl4/bigrat.pl bigrat.pl )
( cd usr/lib/perl4 ; rm -rf cacheout.pl )
( cd usr/lib/perl4 ; ln -sf /cdrom/live/usr/lib/perl4/cacheout.pl cacheout.pl )
( cd usr/lib/perl4 ; rm -rf chat2.pl )
( cd usr/lib/perl4 ; ln -sf /cdrom/live/usr/lib/perl4/chat2.pl chat2.pl )
( cd usr/lib/perl4 ; rm -rf complete.pl )
( cd usr/lib/perl4 ; ln -sf /cdrom/live/usr/lib/perl4/complete.pl complete.pl )
( cd usr/lib/perl4 ; rm -rf ctime.pl )
( cd usr/lib/perl4 ; ln -sf /cdrom/live/usr/lib/perl4/ctime.pl ctime.pl )
( cd usr/lib/perl4 ; rm -rf dumpvar.pl )
( cd usr/lib/perl4 ; ln -sf /cdrom/live/usr/lib/perl4/dumpvar.pl dumpvar.pl )
( cd usr/lib/perl4 ; rm -rf exceptions.pl )
( cd usr/lib/perl4 ; ln -sf /cdrom/live/usr/lib/perl4/exceptions.pl exceptions.pl )
( cd usr/lib/perl4 ; rm -rf fastcwd.pl )
( cd usr/lib/perl4 ; ln -sf /cdrom/live/usr/lib/perl4/fastcwd.pl fastcwd.pl )
( cd usr/lib/perl4 ; rm -rf find.pl )
( cd usr/lib/perl4 ; ln -sf /cdrom/live/usr/lib/perl4/find.pl find.pl )
( cd usr/lib/perl4 ; rm -rf finddepth.pl )
( cd usr/lib/perl4 ; ln -sf /cdrom/live/usr/lib/perl4/finddepth.pl finddepth.pl )
( cd usr/lib/perl4 ; rm -rf flush.pl )
( cd usr/lib/perl4 ; ln -sf /cdrom/live/usr/lib/perl4/flush.pl flush.pl )
( cd usr/lib/perl4 ; rm -rf getcwd.pl )
( cd usr/lib/perl4 ; ln -sf /cdrom/live/usr/lib/perl4/getcwd.pl getcwd.pl )
( cd usr/lib/perl4 ; rm -rf getopt.pl )
( cd usr/lib/perl4 ; ln -sf /cdrom/live/usr/lib/perl4/getopt.pl getopt.pl )
( cd usr/lib/perl4 ; rm -rf getopts.pl )
( cd usr/lib/perl4 ; ln -sf /cdrom/live/usr/lib/perl4/getopts.pl getopts.pl )
( cd usr/lib/perl4 ; rm -rf importenv.pl )
( cd usr/lib/perl4 ; ln -sf /cdrom/live/usr/lib/perl4/importenv.pl importenv.pl )
( cd usr/lib/perl4 ; rm -rf look.pl )
( cd usr/lib/perl4 ; ln -sf /cdrom/live/usr/lib/perl4/look.pl look.pl )
( cd usr/lib/perl4 ; rm -rf newgetopt.pl )
( cd usr/lib/perl4 ; ln -sf /cdrom/live/usr/lib/perl4/newgetopt.pl newgetopt.pl )
( cd usr/lib/perl4 ; rm -rf open2.pl )
( cd usr/lib/perl4 ; ln -sf /cdrom/live/usr/lib/perl4/open2.pl open2.pl )
( cd usr/lib/perl4 ; rm -rf perldb.pl )
( cd usr/lib/perl4 ; ln -sf /cdrom/live/usr/lib/perl4/perldb.pl perldb.pl )
( cd usr/lib/perl4 ; rm -rf pwd.pl )
( cd usr/lib/perl4 ; ln -sf /cdrom/live/usr/lib/perl4/pwd.pl pwd.pl )
( cd usr/lib/perl4 ; rm -rf shellwords.pl )
( cd usr/lib/perl4 ; ln -sf /cdrom/live/usr/lib/perl4/shellwords.pl shellwords.pl )
( cd usr/lib/perl4 ; rm -rf stat.pl )
( cd usr/lib/perl4 ; ln -sf /cdrom/live/usr/lib/perl4/stat.pl stat.pl )
( cd usr/lib/perl4 ; rm -rf syslog.pl )
( cd usr/lib/perl4 ; ln -sf /cdrom/live/usr/lib/perl4/syslog.pl syslog.pl )
( cd usr/lib/perl4 ; rm -rf termcap.pl )
( cd usr/lib/perl4 ; ln -sf /cdrom/live/usr/lib/perl4/termcap.pl termcap.pl )
( cd usr/lib/perl4 ; rm -rf timelocal.pl )
( cd usr/lib/perl4 ; ln -sf /cdrom/live/usr/lib/perl4/timelocal.pl timelocal.pl )
( cd usr/lib/perl4 ; rm -rf validate.pl )
( cd usr/lib/perl4 ; ln -sf /cdrom/live/usr/lib/perl4/validate.pl validate.pl )
( cd usr/man/preformat/cat1 ; rm -rf a2p.1.gz )
( cd usr/man/preformat/cat1 ; ln -sf /cdrom/live/usr/man/preformat/cat1/a2p.1.gz a2p.1.gz )
( cd usr/man/preformat/cat1 ; rm -rf h2ph.1.gz )
( cd usr/man/preformat/cat1 ; ln -sf /cdrom/live/usr/man/preformat/cat1/h2ph.1.gz h2ph.1.gz )
( cd usr/man/preformat/cat1 ; rm -rf perl.1.gz )
( cd usr/man/preformat/cat1 ; ln -sf /cdrom/live/usr/man/preformat/cat1/perl.1.gz perl.1.gz )
( cd usr/man/preformat/cat1 ; rm -rf s2p.1.gz )
( cd usr/man/preformat/cat1 ; ln -sf /cdrom/live/usr/man/preformat/cat1/s2p.1.gz s2p.1.gz )
( cd usr/src/perl-4.036 ; rm -rf perl.udf )
( cd usr/src/perl-4.036 ; ln -sf /cdrom/live/usr/src/perl-4.036/perl.udf perl.udf )
( cd usr/src/perl-4.036 ; rm -rf Artistic )
( cd usr/src/perl-4.036 ; ln -sf /cdrom/live/usr/src/perl-4.036/Artistic Artistic )
( cd usr/src/perl-4.036 ; rm -rf README )
( cd usr/src/perl-4.036 ; ln -sf /cdrom/live/usr/src/perl-4.036/README README )
( cd usr/src/perl-4.036 ; rm -rf README.1st )
( cd usr/src/perl-4.036 ; ln -sf /cdrom/live/usr/src/perl-4.036/README.1st README.1st )
